@@ -11,7 +11,7 @@ use File::GlobMapper;
 require Exporter;
 our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $HAS_ENCODE);
 @ISA = qw(Exporter);
-$VERSION = '2.080';
+$VERSION = '2.083';
 
 @EXPORT = qw( isaFilehandle isaFilename isaScalar
               whatIsInput whatIsOutput
@@ -977,6 +977,14 @@ sub equal
            $self->[HIGH] == $other->[HIGH] ;
 }
 
+sub isZero
+{
+    my $self = shift;
+
+    return $self->[LOW]  == 0 &&
+           $self->[HIGH] == 0 ;
+}
+
 sub gt
 {
     my $self = shift;
