@@ -4,30 +4,30 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.080 qw(:Status );
-use IO::Compress::RawDeflate 2.080 ();
-use IO::Compress::Adapter::Deflate 2.080 ;
-use IO::Compress::Adapter::Identity 2.080 ;
-use IO::Compress::Zlib::Extra 2.080 ;
-use IO::Compress::Zip::Constants 2.080 ;
+use IO::Compress::Base::Common  2.083 qw(:Status );
+use IO::Compress::RawDeflate 2.083 ();
+use IO::Compress::Adapter::Deflate 2.083 ;
+use IO::Compress::Adapter::Identity 2.083 ;
+use IO::Compress::Zlib::Extra 2.083 ;
+use IO::Compress::Zip::Constants 2.083 ;
 
 use File::Spec();
 use Config;
 
-use Compress::Raw::Zlib  2.080 (); 
+use Compress::Raw::Zlib  2.083 (); 
 
 BEGIN
 {
     eval { require IO::Compress::Adapter::Bzip2 ; 
-           import  IO::Compress::Adapter::Bzip2 2.080 ; 
+           import  IO::Compress::Adapter::Bzip2 2.083 ; 
            require IO::Compress::Bzip2 ; 
-           import  IO::Compress::Bzip2 2.080 ; 
+           import  IO::Compress::Bzip2 2.083 ; 
          } ;
          
     eval { require IO::Compress::Adapter::Lzma ; 
-           import  IO::Compress::Adapter::Lzma 2.080 ; 
+           import  IO::Compress::Adapter::Lzma 2.083 ; 
            require IO::Compress::Lzma ; 
-           import  IO::Compress::Lzma 2.080 ; 
+           import  IO::Compress::Lzma 2.083 ; 
          } ;
 }
 
@@ -36,7 +36,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $ZipError);
 
-$VERSION = '2.080';
+$VERSION = '2.083';
 $ZipError = '';
 
 @ISA = qw(IO::Compress::RawDeflate Exporter);
@@ -1081,9 +1081,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeIn => 0|1 >>
 
-When reading from a file or filehandle, set C<binmode> before reading.
-
-Defaults to 0.
+This option is now a no-op. All files will be read in binmode.
 
 =item C<< Append => 0|1 >>
 
