@@ -5,15 +5,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.080 qw(:Status );
-use IO::Compress::Zlib::Constants 2.080 ;
+use IO::Compress::Base::Common  2.083 qw(:Status );
+use IO::Compress::Zlib::Constants 2.083 ;
 
-use IO::Uncompress::RawInflate  2.080 ;
+use IO::Uncompress::RawInflate  2.083 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $InflateError);
 
-$VERSION = '2.080';
+$VERSION = '2.083';
 $InflateError = '';
 
 @ISA    = qw(IO::Uncompress::RawInflate Exporter);
@@ -399,10 +399,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeOut => 0|1 >>
 
-When writing to a file or filehandle, set C<binmode> before writing to the
-file.
-
-Defaults to 0.
+This option is now a no-op. All files will be written  in binmode.
 
 =item C<< Append => 0|1 >>
 
