@@ -5,16 +5,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use Compress::Raw::Zlib  2.080 ;
-use IO::Compress::Base::Common  2.080 qw(:Status );
+use Compress::Raw::Zlib  2.083 ;
+use IO::Compress::Base::Common  2.083 qw(:Status );
 
-use IO::Uncompress::Base  2.080 ;
-use IO::Uncompress::Adapter::Inflate  2.080 ;
+use IO::Uncompress::Base  2.083 ;
+use IO::Uncompress::Adapter::Inflate  2.083 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $RawInflateError);
 
-$VERSION = '2.080';
+$VERSION = '2.083';
 $RawInflateError = '';
 
 @ISA    = qw(IO::Uncompress::Base Exporter);
@@ -547,10 +547,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeOut => 0|1 >>
 
-When writing to a file or filehandle, set C<binmode> before writing to the
-file.
-
-Defaults to 0.
+This option is now a no-op. All files will be written  in binmode.
 
 =item C<< Append => 0|1 >>
 
